# coding: utf-8

"""
    ARLAS Exploration API

    Explore the content of ARLAS collections  # noqa: E501

    OpenAPI spec version: 14.0.0-beta.4
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import arlas_api_python
from arlas_api_python.api.collections_api import CollectionsApi  # noqa: E501
from arlas_api_python.rest import ApiException


class TestCollectionsApi(unittest.TestCase):
    """CollectionsApi unit test stubs"""

    def setUp(self):
        self.api = arlas_api_python.api.collections_api.CollectionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete(self):
        """Test case for delete

        Delete a collection reference  # noqa: E501
        """
        pass

    def test_export_collections(self):
        """Test case for export_collections

        Get all collection references as a json file  # noqa: E501
        """
        pass

    def test_get(self):
        """Test case for get

        Get a collection reference  # noqa: E501
        """
        pass

    def test_get_all(self):
        """Test case for get_all

        Get all collection references  # noqa: E501
        """
        pass

    def test_import_collections(self):
        """Test case for import_collections

        Add collection references from a json file  # noqa: E501
        """
        pass

    def test_put(self):
        """Test case for put

        Add a collection reference  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
